@@ -4,22 +4,19 @@ from django.template import RequestContext
 from django.utils.translation import ugettext_lazy as _
 
 from cms.plugin_rendering import render_placeholder
-from cms.admin.placeholderadmin import PlaceholderAdmin
+from cms.admin.placeholderadmin import PlaceholderAdminMixin
 
 from zinnia.models import Entry
 from zinnia.admin.entry import EntryAdmin
 from zinnia.settings import ENTRY_BASE_MODEL
 
 
-class EntryPlaceholderAdmin(PlaceholderAdmin, EntryAdmin):
+class EntryPlaceholderAdmin(PlaceholderAdminMixin, EntryAdmin):
     """
     EntryPlaceholder Admin
     """
     fieldsets = (
-        (None, {'fields': ('title', 'image', 'status')}),
-        (_('Content'), {'fields': ('content_placeholder',),
-                        'classes': ('plugin-holder',
-                                    'plugin-holder-nopage')})) + \
+        (_('Content'), {'fields': (('title', 'status'), 'image')}),) + \
         EntryAdmin.fieldsets[1:]
 
     def save_model(self, request, entry, form, change):
@@ -28,7 +25,8 @@ class EntryPlaceholderAdmin(PlaceholderAdmin, EntryAdmin):
         of the placeholder
         """
         context = RequestContext(request)
-        entry.content = render_placeholder(entry.content_placeholder, context)
+        content = render_placeholder(entry.content_placeholder, context)
+        entry.content = content or ''
         super(EntryPlaceholderAdmin, self).save_model(
             request, entry, form, change)
 
